@@ -1,4 +1,5 @@
 """The API that will be exposed to users of this package"""
+import re
 from typing import TextIO
 
 from hcl2.parser import hcl2
@@ -17,8 +18,13 @@ def loads(text: str) -> dict:
     # Append a new line as a temporary fix
 
     # Avoid catastrophic backtracking on missing quote marks
+    multi_line_string_denominator = ""
     for line in text.split('\n'):
-        if line.replace('\\"', '').count('"') % 2 != 0:
+        if '= <<' in line:
+            multi_line_string_denominator = line.split('= <<')[1]
+        elif re.match(rf'\s*{multi_line_string_denominator}', line):
+            multi_line_string_denominator = ""
+        elif multi_line_string_denominator == "" and line.replace('\\"', '').count('"') % 2 != 0:
             raise ValueError(f"Line has unclosed quote marks: {line}")
 
     return hcl2.parse(text + "\n")
